@@ -7,12 +7,6 @@ from elog_cli.auth_manager import AuthManager
 def login(ctx, login_type):
     """Authenticate using the chosen login type."""
     auth_manager: AuthManager = ctx.obj["auth_manager"]  # Retrieve shared AuthManager
-    try:
-        auth_manager.login(login_type)
-        print("Login successful!")
-    except Exception as e:
-        click.echo(f"Authentication failed: {e}")
-        return
-    except ValueError as e:
-        click.echo(f"Invalid login type specified: {e}")
-        return
+    auth_manager.login(login_type)
+    print("Login successful!")
+
