@@ -1,3 +1,6 @@
+import click
+import jwt
+
 class TokenLogin:
     def __init__(self, static_token=None):
         self.static_token = static_token
@@ -21,13 +24,16 @@ class TokenLogin:
 
     def login(self):
         """Ask the user to paste the token and save it in the AuthManager."""
+        # Step 1: Ask user to paste the token
+        self.static_token = input("Please paste your static token: ")
+        
+        # Step 2: Check for token validity
         try:
-            # Step 1: Ask user to paste the token
-            self.static_token = input("Please paste your static token: ")
+            jwt.decode(self.static_token, options={"verify_signature": False})
+        except jwt.InvalidTokenError:
+            raise click.ClickException("Invalid token")
+
+        # Step 3: Save the token in AuthManager
+        token_data = {"access_token": self.static_token}
+        return token_data
 
-            # Step 2: Save the token in AuthManager
-            token_data = {"access_token": self.static_token}
-            return token_data
-        except Exception as e:
-            print(f"Error during login: {e}")
-            raise
